==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/gl.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "Non é posíbel crear o documento",
    "You don't have permission to rename this document" : "Vostede non ten permisos para cambiarlle o nome a este documento",
    "Directory saved successfully." : "O directorio foi gardado satisfactoriamente,.",
    "An error occurred while changing directory." : "Produciuse un erro ao cambiar o directorio.",
    "Saved" : "Gardado",
    "Format filter server is down or misconfigured" : "O servidor de filtro de formato está sen servizo ou mal configurado",
    "Conversion failed. Check log for details." : "Produciuse un fallo na conversión. Comprobe o rexistro para obter máis detalles.",
    "document-styles" : "estilos do documento",
    "document-content" : "contido do documento",
    "bold" : "negra",
    "italic" : "cursiva",
    "solid" : "sólida",
    "pt" : "pt",
    "Saving..." : "Gardando...",
    "Failed to load documents." : "Non foi posíbel cargar os documentos.",
    "No documents were found. Upload or create a document to get started!" : "Non se atopou ningún documento. Envíe un documento para comezar!",
    "No connection to server. Trying to reconnect." : "Sen conexión co servidor. Tentando conectar de novo.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Deixar esta páxina no modo Editor pode provocar que non se garden os datos. Recomendámoslle que empregue o botón «Pechar» no seu canto.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Non foi posíbel cargar o documento. Comprobe se pode abrirse cun editor «odt» externo. Isto tamén pode deberse a que foi eliminado ou a que deixou de compartires recentemente.",
    "Save" : "Gardar",
    "Loading documents..." : "Cargando documentos...",
    "'.' is an invalid file name." : "«.» é un nome de ficheiro incorrecto",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome incorrecto, non se permite «\\», «/», «<», «>», «:», «\"», «|», «?» e «*».",
    "Align Left" : "Aliñar á esquerda",
    "Alignment" : "Aliñamento",
    "Align Right" : "Aliñar á dereita",
    "Annotate" : "Anotar",
    "Background" : "Fondo",
    "Bold" : "Negra",
    "Bottom" : "Abaixo",
    "Cancel" : "Cancelar",
    "Center" : "Centrar",
    "Clone" : "Clonar",
    "Clone this Style" : "Clonar este estilo",
    "Close" : "Pechar",
    "Color" : "Cor",
    "Create" : "Crear",
    "Decrease Indent" : "Diminuír a sangría",
    "Default Style" : "Estilo predeterminado",
    "Delete" : "Eliminar",
    "Family" : "Familia",
    "Font" : "Tipo de letra",
    "Font Effects" : "Efectos das letras",
    "Format" : "Formato",
    "Increase Indent" : "Aumentar a sangría",
    "Insert Image" : "Inserir unha imaxe",
    "Invite Members" : "Convidar a membros",
    "Italic" : "Cursiva",
    "Justified" : "Xustificado",
    "Justify" : "Xustificar",
    "Left" : "Esquerda",
    "Loading" : "Cargando",
    "Members" : "Membros",
    "New Name:" : "Novo nome:",
    "OK" : "Aceptar",
    "Open" : "Abrir",
    "Options" : "Opcións",
    "Paragraph..." : "Parágrafo...",
    "Paragraph Styles" : "Estilos de parágrafo",
    "Redo" : "Refacer",
    "Right" : "Dereita",
    "Size" : "Tamaño",
    "Spacing" : "Espazado",
    "Strikethrough" : "Riscado",
    "Style" : "Estilo",
    "Text" : "Texto",
    "Top" : "Arriba",
    "Underline" : "Subliñado",
    "Undo" : "Desfacer",
    "Unknown Author" : "Autor descoñecido",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "guest" : "convidado",
    "MS Word support (requires openOffice/libreOffice)" : "Compatibilidade con MS Word (require OpenOffice/LibreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "OpenOffice/LibreOffice está instalado neste servidor. A ruta ao binario fornecese mediante preview_libreoffice_path en config.php",
    "External" : "Externo",
    "openOffice/libreOffice is installed on external server running a format filter server" : "OpenOffice/LibreOffice está instalado nun servidor externo executando un servidor de filtro de formato",
    "Disabled" : "Desactivado",
    "No MS Word support" : "Sen compatibilidade con MS Word",
    "scheme://domain.tld[:port]" : "scheme://dominio.tld[:porto]",
    "Server URL" : "URL do servidor",
    "Apply and test" : "Aplicar e probar",
    "New document" : "Novo documento",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "Upload" : "Enviar",
    "Save new documents to" : "Gardar os novos documentos en",
    "Wrong password. Please retry." : "Contrasinal incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal",
    "Guest %s" : "Convidado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Esta ligazón caducou ou xa non existe. Póñase en contacto coa persoa que o compartiu con vostede para obter máis información.",
    "Advanced feature-set" : "Conxunto de funcións avanzadas",
    "(Unstable)" : "(Inestábel)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/gl.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "Non é posíbel crear o documento",
    "You don't have permission to rename this document" : "Vostede non ten permisos para cambiarlle o nome a este documento",
    "Directory saved successfully." : "O directorio foi gardado satisfactoriamente,.",
    "An error occurred while changing directory." : "Produciuse un erro ao cambiar o directorio.",
    "Saved" : "Gardado",
    "Format filter server is down or misconfigured" : "O servidor de filtro de formato está sen servizo ou mal configurado",
    "Conversion failed. Check log for details." : "Produciuse un fallo na conversión. Comprobe o rexistro para obter máis detalles.",
    "Saving..." : "Gardando...",
    "Failed to load documents." : "Non foi posíbel cargar os documentos.",
    "No documents were found. Upload or create a document to get started!" : "Non se atopou ningún documento. Envíe un documento para comezar!",
    "No connection to server. Trying to reconnect." : "Sen conexión co servidor. Tentando conectar de novo.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Deixar esta páxina no modo Editor pode provocar que non se garden os datos. Recomendámoslle que empregue o botón «Pechar» no seu canto.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Non foi posíbel cargar o documento. Comprobe se pode abrirse cun editor «odt» externo. Isto tamén pode deberse a que foi eliminado ou a que deixou de compartires recentemente.",
    "Save" : "Gardar",
    "Loading documents..." : "Cargando documentos...",
    "'.' is an invalid file name." : "«.» é un nome de ficheiro incorrecto",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome incorrecto, non se permite «\\», «/», «<», «>», «:», «\"», «|», «?» e «*».",
    "Align Left" : "Aliñar á esquerda",
    "Alignment" : "Aliñamento",
    "Align Right" : "Aliñar á dereita",
    "Annotate" : "Anotar",
    "Background" : "Fondo",
    "Bold" : "Negra",
    "Bottom" : "Abaixo",
    "Cancel" : "Cancelar",
    "Center" : "Centrar",
    "Clone" : "Clonar",
    "Clone this Style" : "Clonar este estilo",
    "Close" : "Pechar",
    "Color" : "Cor",
    "Create" : "Crear",
    "Decrease Indent" : "Diminuír a sangría",
    "Default Style" : "Estilo predeterminado",
    "Delete" : "Eliminar",
    "Family" : "Familia",
    "Font" : "Tipo de letra",
    "Font Effects" : "Efectos das letras",
    "Format" : "Formato",
    "Increase Indent" : "Aumentar a sangría",
    "Insert Image" : "Inserir unha imaxe",
    "Invite Members" : "Convidar a membros",
    "Italic" : "Cursiva",
    "Justified" : "Xustificado",
    "Justify" : "Xustificar",
    "Left" : "Esquerda",
    "Loading" : "Cargando",
    "Members" : "Membros",
    "New Name:" : "Novo nome:",
    "OK" : "Aceptar",
    "Open" : "Abrir",
    "Options" : "Opcións",
    "Paragraph..." : "Parágrafo...",
    "Paragraph Styles" : "Estilos de parágrafo",
    "Redo" : "Refacer",
    "Right" : "Dereita",
    "Size" : "Tamaño",
    "Spacing" : "Espazado",
    "Strikethrough" : "Riscado",
    "Style" : "Estilo",
    "Text" : "Texto",
    "Top" : "Arriba",
    "Underline" : "Subliñado",
    "Undo" : "Desfacer",
    "Unknown Author" : "Autor descoñecido",
    "Shared" : "Compartido",
    "Error" : "Erro",
    "Error while sharing" : "Produciuse un erro ao compartir",
    "Error while unsharing" : "Produciuse un erro ao deixar de compartir",
    "Error while changing permissions" : "Produciuse un erro ao cambiar os permisos",
    "Shared with you and the group {group} by {owner}" : "Compartido con vostede e co grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vostede por {owner}",
    "Share with users or groups …" : "Compartir con usuarios ou grupos ...",
    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos ou usuarios remotos ...",
    "Share" : "Compartir",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con outra xente ou con outros ownClouds empregando a sintaxe «nomeusuario@exemplo.com/ouwncloud»",
    "Share link" : "Ligazón para compartir",
    "The public link will expire no later than {days} days after it is created" : "A ligazón pública caducará, a máis tardar, {days} días após a súa creación",
    "Link" : "Ligazón",
    "Password protect" : "Protexido con contrasinal",
    "Password" : "Contrasinal",
    "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
    "Allow editing" : "Permitir a edición",
    "Email link to person" : "Enviar ligazón por correo",
    "Send" : "Enviar",
    "Set expiration date" : "Definir a data de caducidade",
    "Expiration" : "Caducidade",
    "Expiration date" : "Data de caducidade",
    "An error occured. Please try again" : "Produciuse un erro, ténteo de novo",
    "Adding user..." : "Engadindo usuario...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Non se permite volver compartir",
    "Shared in {item} with {user}" : "Compartido en {item} con {user}",
    "Unshare" : "Deixar de compartir",
    "notify by email" : "notificar por correo",
    "can share" : "pode compartir",
    "can edit" : "pode editar",
    "access control" : "control de acceso",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "Password protected" : "Protexido con contrasinal",
    "Error unsetting expiration date" : "Produciuse un erro ao retirar a data de caducidade",
    "Error setting expiration date" : "Produciuse un erro ao definir a data de caducidade",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo enviado",
    "Warning" : "Aviso",
    "Edit" : "Editar",
    "guest" : "convidado",
    "MS Word support (requires openOffice/libreOffice)" : "Compatibilidade con MS Word (require OpenOffice/LibreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "OpenOffice/LibreOffice está instalado neste servidor. A ruta ao binario fornecese mediante preview_libreoffice_path en config.php",
    "External" : "Externo",
    "openOffice/libreOffice is installed on external server running a format filter server" : "OpenOffice/LibreOffice está instalado nun servidor externo executando un servidor de filtro de formato",
    "Disabled" : "Desactivado",
    "No MS Word support" : "Sen compatibilidade con MS Word",
    "scheme://domain.tld[:port]" : "scheme://dominio.tld[:porto]",
    "Server URL" : "URL do servidor",
    "Apply and test" : "Aplicar e probar",
    "New document" : "Novo documento",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "Upload" : "Enviar",
    "Save new documents to" : "Gardar os novos documentos en",
    "Wrong password. Please retry." : "Contrasinal incorrecto. Ténteo de novo.",
    "Guest %s" : "Convidado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Esta ligazón caducou ou xa non existe. Póñase en contacto coa persoa que o compartiu con vostede para obter máis información.",
    "Advanced feature-set" : "Conxunto de funcións avanzadas",
    "(Unstable)" : "(Inestábel)"
},
"nplurals=2; plural=(n != 1);");
